==> haskell-data-default-class-0.1.2.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-class
version:              0.1.2.2
visibility:           public
id:                   data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
key:                  data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             A class for types with a default value
description:
    This module defines a class for types with a default value.
    It also defines '\''Default'\'' instances for the types '\''Int'\'', '\''Int8'\'',
    '\''Int16'\'', '\''Int32'\'', '\''Int64'\'', '\''Word'\'', '\''Word8'\'', '\''Word16'\'', '\''Word32'\'', '\''Word64'\'',
    '\''Integer'\'', '\''Float'\'', '\''Double'\'', '\''Ratio'\'', '\''Complex'\'', '\''CShort'\'', '\''CUShort'\'',
    '\''CInt'\'', '\''CUInt'\'', '\''CLong'\'', '\''CULong'\'', '\''CLLong'\'', '\''CULLong'\'', '\''CPtrdiff'\'',
    '\''CSize'\'', '\''CSigAtomic'\'', '\''CIntPtr'\'', '\''CUIntPtr'\'', '\''CIntMax'\'', '\''CUIntMax'\'',
    '\''CClock'\'', '\''CTime'\'', '\''CUSeconds'\'', '\''CSUSeconds'\'', '\''CFloat'\'', '\''CDouble'\'', '\''(->)'\'',
    '\''IO'\'', '\''Maybe'\'', '\''()'\'', '\''[]'\'', '\''Ordering'\'', '\''Any'\'', '\''All'\'', '\''Last'\'', '\''First'\'', '\''Sum'\'',
    '\''Product'\'', '\''Endo'\'', '\''Dual'\'', and tuples.

category:             Data
abi:                  8873a37895eb80bf7ef31f0e8347a3e5
exposed:              True
exposed-modules:      Data.Default.Class
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-default-class-0.1.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-default-class-0.1.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-default-class-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-class
hs-libraries:         HSdata-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-data-default-class/html/data-default-class.haddock

haddock-html:         /usr/share/doc/haskell-data-default-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-class-0.1.2.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-class
version:              0.1.2.2
visibility:           public
id:                   data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
key:                  data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             A class for types with a default value
description:
    This module defines a class for types with a default value.
    It also defines '\''Default'\'' instances for the types '\''Int'\'', '\''Int8'\'',
    '\''Int16'\'', '\''Int32'\'', '\''Int64'\'', '\''Word'\'', '\''Word8'\'', '\''Word16'\'', '\''Word32'\'', '\''Word64'\'',
    '\''Integer'\'', '\''Float'\'', '\''Double'\'', '\''Ratio'\'', '\''Complex'\'', '\''CShort'\'', '\''CUShort'\'',
    '\''CInt'\'', '\''CUInt'\'', '\''CLong'\'', '\''CULong'\'', '\''CLLong'\'', '\''CULLong'\'', '\''CPtrdiff'\'',
    '\''CSize'\'', '\''CSigAtomic'\'', '\''CIntPtr'\'', '\''CUIntPtr'\'', '\''CIntMax'\'', '\''CUIntMax'\'',
    '\''CClock'\'', '\''CTime'\'', '\''CUSeconds'\'', '\''CSUSeconds'\'', '\''CFloat'\'', '\''CDouble'\'', '\''(->)'\'',
    '\''IO'\'', '\''Maybe'\'', '\''()'\'', '\''[]'\'', '\''Ordering'\'', '\''Any'\'', '\''All'\'', '\''Last'\'', '\''First'\'', '\''Sum'\'',
    '\''Product'\'', '\''Endo'\'', '\''Dual'\'', and tuples.

category:             Data
abi:                  fe42172cec1dc353b69780cbe3e795f6
exposed:              True
exposed-modules:      Data.Default.Class
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-default-class-0.1.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-default-class-0.1.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-default-class-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-class
hs-libraries:         HSdata-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-data-default-class/html/data-default-class.haddock

haddock-html:         /usr/share/doc/haskell-data-default-class/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
